@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1318 2015-05-06 10:42:03Z mwall $
+# $Id: owfs.py 1377 2015-10-27 22:32:30Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -169,7 +169,8 @@ import weewx
 from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
-VERSION = "0.13"
+DRIVER_NAME = 'OWFS'
+DRIVER_VERSION = "0.16"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'owfs: %s' % msg)
@@ -294,8 +295,7 @@ def inspeed_winddir(key, path, last_data, ts):
     Formula from the Hobby-Boards Inspeed anemometer user manual."""
     vdd = get_float('%s%s' % (path, '/VDD'))
     vad = get_float('%s%s' % (path, '/VAD'))
-    d = (400*(vad-0.05*vdd))/vdd
-    return d
+    return (400*(vad-0.05*vdd))/vdd if vdd else None
 
 def aag_windspeed(key, path, last_data, ts):
     ws = average(key, "%s%s" % (path, "/counters.A"), last_data, ts)
@@ -408,7 +408,7 @@ class OWFSDriver(weewx.drivers.AbstractDevice):
         self.last_data = {}
         self.units = weewx.US if self.unit_system == 'us' else weewx.METRIC
 
-        loginf('driver version is %s' % VERSION)
+        loginf('driver version is %s' % DRIVER_VERSION)
         loginf('interface is %s' % self.interface)
         loginf('sensor map is %s' % self.sensor_map)
         loginf('sensor type map is %s' % self.sensor_type)
@@ -479,7 +479,7 @@ class OWFSService(weewx.engine.StdService):
         self.last_data = {}
         self.units = weewx.US if self.unit_system == 'us' else weewx.METRIC
 
-        loginf('service version is %s' % VERSION)
+        loginf('service version is %s' % DRIVER_VERSION)
         loginf('binding is %s' % self.binding)
         loginf('interface is %s' % self.interface)
         loginf('sensor map is %s' % self.sensor_map)
@@ -559,7 +559,7 @@ if __name__ == '__main__':
         (options, args) = parser.parse_args()
 
         if options.version:
-            print "owfs version %s" % VERSION
+            print "owfs version %s" % DRIVER_VERSION
             exit(1)
 
         # default to usb for the interface
